﻿/*
 * LSComponent 日期工具类
 * author liliuqing
 * modified by liliuqing
 * version: "2018.05.31.01"
 */
(function () {
    /**
     * 关于日期操作的对象
     */
    var Dite = function () {

        /**
         * 时间转化为季度
         *
         * @param date
         *            {string}
         * @param fmt
         *            {string}
         * @example dateFormat("2013-01-02","yyyy年MM月dd日 hh:mm:ss");
         */
        Dite.prototype.convertToSeason = function (date) {
            var year = date.substring(0, 4);
            var month = date.substring(4, 6);
            var val;
            if (parseInt(month) >= 1 && parseInt(month) <= 3) {
                val = "Q1";
            } else if (parseInt(month) > 3 && parseInt(month) <= 6) {
                val = "Q2";
            } else if (parseInt(month) > 6 && parseInt(month) <= 9) {
                val = "Q3";
            } else {
                val = "Q4";
            }
            delete month;
            month = null;
            return year + val;
        }
        /**
         * 季度转化为时间
         *
         * @param date
         *            {string}
         * @param fmt
         *            {string}
         * @example dateFormat("2013-01-02","yyyy年MM月dd日 hh:mm:ss");
         */
        Dite.prototype.convertToDate = function (date) {
            var num = date.substring(5, 6);
            var year = date.substring(0, 4);
            var month;
            switch (num) {
                case "1":
                    month = "03";
                    break;
                case "2":
                    month = "06";
                    break;
                case "3":
                    month = "09";
                    break;
                case "4":
                    month = "12";
                    break;
            }

            return year + month;
        }


        /**
         * 是否是闰年
         * @param year
         * @returns {boolean}
         */
        Dite.prototype.isLeapYear = function (year) {
            return (((year % 4 === 0) && (year % 100 !== 0)) || (year % 400 === 0))
        }

        /**
         * 当前年当前月的天数
         * @param year
         * @returns {boolean}
         */
        Dite.prototype.getDaysInMonth = function (year, month) {
            return [31, (this.isLeapYear(year) ? 29 : 28), 31, 30, 31, 30, 31, 31, 30, 31, 30, 31][month-1];
        }

        /**
         * 获取日期中的年
         */
        Dite.prototype.getYear = function (date) {
            var value = date.substr(0, 4);
            return value;
        }

        /**
         * 获取日期中的季
         */
        Dite.prototype.getQuarter = function (date) {
            date = date.replace("-", "");
            var month = date.substring(4, 6);
            var val;
            if (parseInt(month) >= 1 && parseInt(month) <= 3) {
                val = "Q1";
            } else if (parseInt(month) > 3 && parseInt(month) <= 6) {
                val = "Q2";
            } else if (parseInt(month) > 6 && parseInt(month) <= 9) {
                val = "Q3";
            } else {
                val = "Q4";
            }

            return val;
        }

        /**
         * 获取日期中的月
         */
        Dite.prototype.getMonth = function (date) {
            var value = date.substr(4, 2);
            return value;
        }

        /**
         * 获取日期中的日
         */
        Dite.prototype.getDay = function (date) {
            var value = date.substr(date.length - 2, date.length);
            return value;
        }

        /**
         * XXXX-XX转化为X月
         */
        Dite.prototype.formatToMonth = function (date) {
            var arrLabel = date.split("-");
            var value = "";
            switch (arrLabel[1]) {
                case "01":
                    value = "1月";
                    break;
                case "02":
                    value = "2月";
                    break;
                case "03":
                    value = "3月";
                    break;
                case "04":
                    value = "4月";
                    break;
                case "05":
                    value = "5月";
                    break;
                case "06":
                    value = "6月";
                    break;
                case "07":
                    value = "7月";
                    break;
                case "08":
                    value = "8月";
                    break;
                case "09":
                    value = "9月";
                    break;
                case "10":
                    value = "10月";
                    break;
                case "11":
                    value = "11月";
                    break;
                case "12":
                    value = "12月";
                    break;
            }
            return value;
        };

        /**
         * XXXX-XX转化为X季度
         */
        Dite.prototype.formatToQuarter = function (date) {
            date=date.replace("-","");
            var month = date.substr(4,6);
            var val;
            if (parseInt(month) >= 1 && parseInt(month) <= 3) {
                val = "1季度";
            } else if (parseInt(month) > 3 && parseInt(month) <= 6) {
                val = "2季度";
            } else if (parseInt(month) > 6 && parseInt(month) <= 9) {
                val = "3季度";
            } else {
                val = "4季度";
            }

            return val;
        };

        /**
         * 时间倒推函数 （时间，时间类型，倒推基数） loadDate(date,3,12)
         */
        Dite.prototype.dateback = function (date, dateType, num, minDate) {
            num = num - 1;
            date = date.replace("-", "");
            var year = date.substring(0, 4);// year
            var month = date.substring(4, 6);// month
            var season = date.substring(5, 6);// season
            var backDate = "";
            if (dateType == 'Y') {// year
                if (minDate) {
                    var minDateYear = parseInt(minDate.substring(0, 4));// get
                    // the
                    // minDate
                    // year
                    backDate = (parseInt(year) - num > minDateYear ? parseInt(year) - num : minDateYear) + "";
                } else {
                    backDate = parseInt(year) - num + "";
                }
            } else if (dateType == 'Q') {// season
                var _a = num % 4;
                var _b = ((num + 1) % 4 == 0 && season == 4) ? parseInt((num) / 4) : parseInt((num + 4 - parseInt(season)) / 4);
                if (minDate) {
                    var minDateYear = parseInt(minDate.substring(0, 4));// get
                    // the
                    // minDate
                    // year
                    var minDateSeason = parseInt(minDate.substring(5, 6));// get
                    // the
                    // minDate
                    // season
                    if (parseInt(year) - _b < minDateYear) {
                        backDate = minDateYear + "Q1";
                    } else {
                        if (parseInt(season) - _a <= 0) {
                            backDate = (parseInt(year) - _b) + "Q" + (4 - (Math.abs((parseInt(season) - _a))));
                        } else {
                            backDate = (parseInt(year) - _b) + "Q" + Math.abs((parseInt(season) - _a));
                        }
                    }
                } else {
                    backDate = (parseInt(year) - _b) + "Q" + Math.abs((parseInt(season) - _a));
                }
            } else if (dateType == 'M') {// month
                var _mBack = 0;// 返回月
                var _yBack = 0;// 返回年

                _mBack = parseInt(month) - num;
                _yBack = parseInt(year);
                if (num >= parseInt(month)) {
                    var yuNum = num - parseInt(month);
                    _mBack = 12 - yuNum % 12;
                    _yBack = _yBack - parseInt(yuNum / 12) - 1;
                }

                backDate = _yBack + "-" + (_mBack > 9 ? _mBack : "0" + _mBack);
                if (minDate) {// 有最小日期的更新处理
                    var minDateYear = parseInt(minDate.substring(0, 4));// year
                    var minDateMonth = parseInt(minDate.substring(4, 6));// month

                    if (minDateYear > _yBack) {
                        backDate = minDate;
                    } else if (minDateYear == _yBack && minDateMonth > _mBack) {
                        backDate = minDate;
                    }
                }

            }
            return backDate;
        };

        /**
         * 获取时间段之前所有的点 （开始时间时间，结束时间，时间类型） loadDate(date,3,12)
         */
        Dite.prototype.dateinterval = function (startDate, endDate, dateType) {
            var dateinterval = [];
            startDate = parseInt(startDate);
            while (startDate <= parseInt(endDate)) {
                dateinterval.push(startDate);
                startDate = startDate + 1;
            }
            return dateinterval;
        };

        /**
         * 将日期类型数据转换成天格式 date 日期类型或字符串 author liliuqing 2015120601
         */
        Dite.prototype.convertToDay = function (value) {
            var date = new Date(value);
            // 年
            var year = date.getFullYear();
            // 月
            var month = date.getMonth() + 1;
            if (month < 10) {// 不足10补0
                month = "0" + month;
            }
            // 日
            var day = date.getDate();
            if (day < 10) {// 不足10补0
                day = "0" + day;
            }
            // 返回值
            var retValue = year + "-" + month + "-" + day;

            return retValue;
        }

        /**
         * 时间粒度type转换器,转换成JS所用单位 1,日；2，月；3，季；4，年
         */
        Dite.prototype.changeDateLDTypeToJS = function (type) {
            var value = "";
            if (type == "YY") {
                value = "Y";
            } else if (type == "MM") {
                value = "M";
            } else if (type == "DD") {
                value = "D";
            } else if (type == "3") {// 季度
                value = "Q";
            }
            return value;
        }

        /**
         * 时间粒度type转换器,转换成数据库中所用type
         */
        Dite.prototype.changeDateLDTypeToOracle = function (type) {
            var value = "";
            if (type == "Y") {
                value = "4";
            } else if (type == "M") {
                value = "2";
            } else if (type == "D") {
                value = "1";
            } else if (type == "Q") {
                value = "3";
            }
            return value;
        }

        /**
         * 获取开始、结束时间时间内所有的时间范围点 startTime:开始时间,字符串类型
         * 年:"YYYY";季:"YYY-QX";月:"YYYY-MM";日:"YYYY-MM-DD";小时:"0,1,2,...23";分:"0,1,2,...59";秒:"0,1,2,....59"
         * endTime:结束时间，字符串类型 dateType:时间类型
         * 年:"Y";季:"Q";月:"M";日:"D";小时:"HH";分:"MM";秒:"SS" author:liliuqing
         * 2015120601
         */
        Dite.prototype.getDateRange = function (startTime, endTime, dateType) {
            var rangeValues = [];

            // 开始日期
            var startDate;
            // 结束日期
            var endDate;
            if (dateType == "Y" || dateType == "HH" || dateType == "MM" || dateType == "SS") {
                startDate = parseInt(startTime);
                endDate = parseInt(endTime);
                while (startDate <= endDate) {
                    rangeValues.push(startDate);
                    startDate += 1;
                }
            } else if (dateType == "D") {
                // 秒计算单位
                startDate = new Date(startTime.toString()).getTime();
                endDate = new Date(endTime.toString()).getTime();
                while (startDate <= endDate) {
                    var tempDate = new Date(startDate);
                    rangeValues.push(LSComponent.Utils.Date.convertToDay(tempDate));
                    startDate = startDate + 24 * 60 * 60 * 1000;
                }
            } else if (dateType == "M") {

            }

            return rangeValues;
        }
        Dite.prototype.QDATETYPE=1;//时间季度的参数类型
        /**
         * 日期格式化
         * qDateType季度数据类型  默认为2018Q1的形式  传为1 则代表为201803这种格式
         *
         */
        Dite.prototype.DateFormat = function (date, type,qDateType) {
            var formatDateStr;
            date = date.replace("-", "");
            if (type == "YYYYMM") {
                formatDateStr = date.substr(0, 4) + date.substr(4, 2);
            } else if (type == "YYYY-MM") {
                formatDateStr = date.substr(0, 4) + "-" + date.substr(4, 2);
            } else if (type == "YYYY") {
                formatDateStr = date;
            } else if (type == "YYYY年") {
                formatDateStr = date + "年";
            } else if (type == "YYYY年M月") {
                var month = (date.substr(4, 1) == "0" ? "" : date.substr(4, 1)) + date.substr(5, 1);
                formatDateStr = date.substr(0, 4) + "年" + month + "月";
            } else if (type == "YYYY年M月D日") {
                formatDateStr = date.substr(0, 4) + "年" + parseInt(date.substr(4, 2)) + "月" + parseInt(date.substr(6, 2)) + "日";
            } else if (type == "YYYYQX") {// 2016Q1,2016Q2
                if(qDateType&&qDateType==this.QDATETYPE){
                    formatDateStr = date.substr(0, 4) + this.getQuarter(date);
                }else{
                    formatDateStr = date.substr(0, 4) + "Q" + date.substr(date.length - 1);
                }
            }else if (type == "YYYY年Q季度") {// 2016Q1,2016Q2
                if(qDateType&&qDateType==this.QDATETYPE){
                    formatDateStr = date.substr(0, 4)+"年" + this.formatToQuarter(date);
                }else{
                    formatDateStr = date.substr(0, 4) + "年" + this.formatToQuarter(this.convertToDate(date.substr(4,1)));
                }
            } else if (type == "YYYY-QX") {// 2016Q1,2016Q2
                if(qDateType&&qDateType==this.QDATETYPE){
                    formatDateStr = date.substr(0, 4) + "-" + this.getQuarter(date);
                }else{
                    formatDateStr =date.substr(0, 4) + "-" + date.substr(date.length - 1);
                }
            } else if (type == "YYYYMMDD") {
                formatDateStr = date.replace(/\-/g, "");
            } else if (type == "YYYY-MM-DD") {
                formatDateStr = date.substr(0, 4) + "-" + date.substr(4, 2) + "-" + date.substr(6, 2);
            }
            return formatDateStr;
        };

        /**
         * 日期格式化 获取年 月 日
         *
         */
        Dite.prototype.GetYMD = function (date, type) {
            var formatDateStr;
            if (date.split("-").length > 0)// 2017-01-12
            {
                if (type == "YYYY") {
                    formatDateStr = date.substr(0, 4);
                } else if (type == "MM") {
                    formatDateStr = date.substr(4, 2);
                } else if (type == "QX") {
                    formatDateStr = date.substr(4, 2);
                } else if (type == "DD") {
                    formatDateStr = date.substr(6, 2);
                }
            } else// 20170112
            {
                if (type == "YYYY") {
                    formatDateStr = date.split("-")[0];
                } else if (type == "MM") {
                    formatDateStr = date.split("-")[1];
                } else if (type == "QX") {
                    formatDateStr = date.split("-")[1];
                } else if (type == "DD") {
                    formatDateStr = date.split("-")[2];
                }

            }

            return formatDateStr;
        };

        /**
         * 获取当前时间的天数，即从当年的一月一号开始
         */
        Dite.prototype.GetDayNumbers = function (date) {
            var dateArr = new Array(31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
            var day = Number(date.substr(6, 2));
            var month = Number(date.substr(4, 2)); // getMonth()是从0开始
            var year = Number(date.substr(0, 4));
            var result = 0;
            for (var i = 0; i < month - 1; i++) {
                result += dateArr[i];
            }
            result += day;
            // 判断是否闰年
            if (month > 1 && (year % 4 == 0 && year % 100 != 0) || year % 400 == 0) {
                result += 1;
            }

            return result;
        };

        /**
         * 获取前一个月的日期 参数输入为YYYYMMDD格式
         */
        Dite.prototype.getPrevDate = function (date) {
            var year = date.substr(0, 4);
            var month = parseInt(date.substr(4, 2));
            var day = date.substr(6, 2);
            var newYear = year;
            var newMonth = month;
            var newDay = day;

            if (month == 1) {
                newYear = parseInt(year) - 1;
                newMonth = 12;
            } else {
                newMonth = month - 1;
            }

            if (newDay > 28 && newMonth == 2) {
                newDay = 28;
            } else if (newDay > 30 && (newMonth == 4 || newMonth == 6 || newMonth == 9 || newMonth == 11)) {
                newDay = 30;
            }

            return newYear + (newMonth < 10 ? "0" : "") + newMonth + newDay;
        };

        /**
         * 获取系统的默认时间,需要添加对时间粒度的判断,一般口径都是最新时间往前推多少个点 source,时间数据源 type,时间粒度
         * Y:年,M:月,Q:季,D:日
         * range,endTime往前推的时间段,例如，往前推几年，往前推几月，往前推几天，为空表示当前年，当前年1月，当前年第一季度，当前年第一天
         * source:[{startTime:"",endTime:""}] <br>
         * return {from: '',//最小时间 to:'',//最大时间 startTime: '',//默认选中时间段的起始时间,
		 * endTime: ''//默认选中时间段的结束时间 }
         */
        Dite.prototype.getSysDateDefault = function (source, type, range) {
//			var source = [ {
//				id : "M",
//				MIN_DATE : "201701",
//				MAX_DATE : "201704"
//			} ];
            var endYear = "", endQuarter = "", endMonth = "", endDay = "";
            var startYear = "", startQuarter = "", startMonth = "", startDay = "";
            var sysDateDefault = {
                from: "",
                to: "",
                startTime: "",
                endTime: ""
            };

            var sysDateDefault = $.extend(true, sysDateDefault, LSComponent.Utils.System.getItemByFieldValues("id", [type], source)[0]);
            sysDateDefault.from = sysDateDefault.MIN_DATE;
            if(!sysDateDefault.to){
                sysDateDefault.to = sysDateDefault.MAX_DATE;
            }

//          if (g_year == null || g_year == undefined || g_year == "") {
//              g_year = this.getYear(sysDateDefault.to);
//          }

            if (type == "Y") {// 年
                // 默认选中的截止时间
//              if (g_year < sysDateDefault.to) {
//                  sysDateDefault.endTime = g_year;
//              } else {
                    sysDateDefault.endTime = sysDateDefault.to;
//              }

                // 默认的起始时间
                if (range == undefined || range == null) {// 不往前推，表示当前年
                    sysDateDefault.startTime = sysDateDefault.to + "";
                } else {
                    sysDateDefault.startTime = sysDateDefault.endTime - range + 1 + "";
                }
            } else if (type == "M") {// 月
                // 默认选中的截止时间
                endYear = this.getYear(sysDateDefault.to);
                endMonth = this.getMonth(sysDateDefault.to);
//              if (g_year < endYear) {
//                  endYear = g_year;
//                  endMonth = "12";
//              }
                sysDateDefault.endTime = endYear + "" + endMonth;

                // 默认的起始时间
                if (range == undefined || range == null) {// 不往前推，表示当前的第一个月
                    sysDateDefault.startTime = endYear + "01";
                    if(sysDateDefault.from>sysDateDefault.startTime){
                        sysDateDefault.startTime=sysDateDefault.from;
                    }
                } else {
                    if (range <= endMonth) {
                        startYear = endYear;
                        startMonth = endMonth - range + 1;
                    } else {
                        startYear = endYear - Math.ceil((range - endMonth) / 12);
                        startMonth = Math.abs(range - endMonth) % 12+1 ;

                    }
                    if (startMonth < 10) {
                        startMonth = "0" + startMonth;
                    }
                    sysDateDefault.startTime = startYear + "" + startMonth;
                    if (sysDateDefault.startTime < sysDateDefault.from) {
                        sysDateDefault.startTime = sysDateDefault.from;
                    }

                }

            } else if (type == "Q") {// 季
                // 默认选中的截止时间
                endYear = this.getYear(sysDateDefault.to);
                endMonth = this.getMonth(sysDateDefault.to);
                if (g_year < endYear) {
                    endYear = g_year;
                    endMonth = "Q4";
                }
                sysDateDefault.endTime = endYear + "" + endMonth;

                // 默认的起始时间
                if (range == undefined || range == null) {// 不往前推，表示当前的第一个月
                    sysDateDefault.startTime = endYear + "Q1";
                    if(sysDateDefault.from>sysDateDefault.startTime){
                        sysDateDefault.startTime=sysDateDefault.from;
                    }
                } else {
                    sysDateDefault.startTime = this.dateback(sysDateDefault.endTime,type,range);
                    // if (range <= endMonth) {
                    //     startYear = endYear;
                    //     startMonth = endMonth - range + 1;
                    // } else {
                    //     startYear = endYear - Math.ceil((range - endMonth) / 12);
                    //     startMonth = 12 - Math.abs(range - endMonth) % 12 + 1;
                    //     if (startMonth < 10) {
                    //         startMonth += "0" + startMonth;
                    //     }
                    // }
                    // sysDateDefault.startTime = startYear + "" + startMonth;
                    if (sysDateDefault.startTime < sysDateDefault.from) {
                        sysDateDefault.startTime = sysDateDefault.from;
                    }

                }

            } else if (type = "D") {// 日
                // 默认选中的截止时间
                endYear = this.getYear(sysDateDefault.to);
                endMonth = this.getMonth(sysDateDefault.to);
                endDay = this.getDay(sysDateDefault.to);
                if (g_year < endYear) {
                    endYear = g_year;
                    endMonth = "12";
                    endDay = "31";
                }
                sysDateDefault.endTime = endYear + "" + endMonth + endDay;

                // 默认的起始时间
                if (range == undefined || range == null) {
                    sysDateDefault.startTime = endYear + "0101";
                    if(sysDateDefault.from>sysDateDefault.startTime){
                        sysDateDefault.startTime=sysDateDefault.from;
                    }
                } else {
                    var endDayNumbers = this.GetDayNumbers(sysDateDefault.to);
                    var  timeTmp=endYear+"/"+endMonth+"/"+endDay;
                    var timesEnd = Date.parse(new Date(timeTmp));
                    var rangeTime=timesEnd-range*24*60*60*1000;
                    var newTime = new Date(rangeTime);
                    var y = newTime.getFullYear();  //获取年
                    var m = newTime.getMonth() + 1;  //获取月
                    m = m < 10 ? '0' + m : m;  //判断月是否大于10
                    var d = newTime.getDate();  //获取日
                    d = d < 10 ? ('0' + d) : d;  //判断日期是否大10
                    sysDateDefault.startTime=y+""+m+d;
                }

            }

            return sysDateDefault;


        };



    };

    LSComponent.Utils = LSComponent.Utils || {};
    LSComponent.Utils.Date = new Dite();

}());