﻿/*
 * LSComponent 系统工具类
 * author liliuqing
 * modified by liliuqing
 * version: "2018.2.27.01"
 */
(function () {
    var System = function () {
        /**
         * 列转行
         * @param source 数据源，长度为1，与keyNames对应
         * @param keyNames source中key对应的中文名
         * @returns {Array}
         */
        System.prototype.colToRow = function (source, keyNames) {
            var list = [];
            for (var key in keyNames) {
                list.push({
                    'name': keyNames[key],
                    'value': source[0][key]
                })
            }
            return list;
        }

        /**
         * 计算自适应的高度
         * @param _fixHeight  固定不变高度
         * @param _rowCount  有几行row的高度可变
         * @returns {number}
         */
        System.prototype.calculateAutoHeight = function (_rowCount) {
            var minRowValue = 160;
            var value = 0;
            var devicePixelWidth = window.screen.width * window.devicePixelRatio;
            var devicePixelHeight = window.screen.height * window.devicePixelRatio;
            var _fixedHeight = 0;
            var _rowIndex = 0;
            $(".fixedHeight").each(function (index) {
                var _height = $(this).outerHeight(true);
                if ($(this).hasClass("ls-panel")) {//panel
                    if ($(this).find(".panel-heading").outerHeight(true)) {//panel或者父容器为显示状态block才可以，否则计算header错误
                        _rowIndex += 1;

                        if (_rowIndex <= _rowCount) {
                            var _marginTop = 0;
                            _marginTop = $(this).css("margin-top");
                            _marginTop = Number(_marginTop.substr(0, _marginTop.length - 2));

                            var _marginBottom = 0;
                            _marginBottom = $(this).css("margin-bottom");
                            _marginBottom = Number(_marginBottom.substr(0, _marginBottom.length - 2));
                            var _paddingTop = 0;
                            var _paddingBottom = 0;

                            _fixedHeight += _marginTop + _marginBottom;

                            var _panelHeading = $(this).find(".panel-heading");
                            _height = _panelHeading.outerHeight(true);
                            _fixedHeight += _height;

                            var _panelBody = $(this).find(".panel-body");

                            _paddingTop = _panelBody.css("padding-top");
                            _paddingTop = Number(_paddingTop.substr(0, _paddingTop.length - 2));
                            _fixedHeight += _paddingTop;

                            _paddingBottom = _panelBody.css("padding-bottom");
                            _paddingBottom = Number(_paddingBottom.substr(0, _paddingBottom.length - 2));
                            _fixedHeight += _paddingBottom;

                        }
                    }

                } else {
                    _fixedHeight += _height;

                }

            });

            //1366*768 <= 当前设备分辨率 <= 1920*1080
            // if (devicePixelWidth >= 1366 && devicePixelWidth <= 1920 && devicePixelHeight >= 768 && devicePixelHeight <= 1080) {
            // if (devicePixelWidth >= 1920 && devicePixelHeight >= 1080) {
            //     value = window.innerHeight - _fixHeight;
            // } else if (devicePixelWidth >= 1366 && devicePixelWidth < 1920 && devicePixelHeight >= 768 && devicePixelHeight < 1080) {
            //     if (top.window.innerHeight == window.screen.height) {//全屏
            //         value = window.innerHeight - _fixHeight;
            //     }
            // }

            // console.log(_fixedHeight);
            if (window.innerHeight >= _fixedHeight + minRowValue * _rowCount) {
                value = (window.innerHeight - _fixedHeight) / _rowCount;
            } else {
                value = minRowValue;
            }

            return value;

        }

        /**
         * 字符串截取N位小数位数，并且添加...
         * @param value
         * @param n
         * @returns {string}
         */
        System.prototype.formatStringWithDot = function (value, n) {
            var retValue = "";
            if (value == undefined || value == null || value == "") {
                retValue = "-";
            } else {
                if (value.length <= n) {
                    retValue = value;
                } else {
                    retValue = value.substr(0, n) + "..."
                }
            }
            return retValue;
        }

        /**
         * 添加【全选】数据项
         */
        System.prototype.addItem_AllSelected = function (source) {
            var item = {"id": "", text: "全部"};
            source.splice(0, 0, item);
            return source;

        };

        /**
         * 通过阶层段间隔值获得间隔列表
         */
        System.prototype.getJCIntervalListByInterval = function (intervalValue) {
            var arr = [];
            for (var i = 0; i < 10; i++) {
                var obj = {};
                if (i == 0) {// 第一个
                    obj.code = i;
                    obj.start = 0;
                    obj.end = 0;
                    obj.label = "全部";
                } else if (i == 9) {// 最后一个
                    obj.code = i;
                    obj.start = (i - 1) * intervalValue + 1;
                    obj.end = 0;
                    obj.label = obj.start + "以上"
                } else {// 其他
                    obj.code = i;
                    if (i == 1) {
                        obj.start = 0;
                    } else {
                        obj.start = (i - 1) * intervalValue + 1;
                    }

                    obj.end = i * intervalValue;
                    obj.label = obj.start + " - " + obj.end;
                }
                arr[i] = obj;
            }

            return arr;
        }

        /**
         * 将源数据源中key的值用逗号串联起来，比如v1,v2,v3,v4....
         */
        System.prototype.getFieldsString = function (key, sourceArr) {
            var retStr = "";
            for (var i = 0; i < sourceArr.length; i++) {
                retStr += sourceArr[i][key] + ",";
            }
            return retStr.substr(0, retStr.length - 1);
        }

        /**
         * 找到所有的叶子节点
         */
        System.prototype.findLeavesNodes = function (sourceArr, childrenKey) {
            var retArr = [];
            for (var s = 0; s < sourceArr.length; s++) {
                var selectedNode = null;
                selectedNode = sourceArr[s];
                if (selectedNode[childrenKey] == null || selectedNode[childrenKey] == undefined) {
                    retArr.push(selectedNode);
                } else {
                    for (var i = 0; i < selectedNode[childrenKey].length; i++) {
                        var childeReturnArr = this.findLeavesNodes([
                            selectedNode[childrenKey][i]
                        ], childrenKey);
                        retArr = retArr.concat(childeReturnArr);
                    }
                }
            }

            return retArr;

        }

        /**
         * wyl 17-3-28
         * 转化 table 的数据
         * 后台分页，返回的内容为数组，数组第一个为table 数据的总页数，第二个开始，为数据
         */
        System.prototype.convertToBootStrapTableSourceByServicePiganation = function (orginSouce) {
            var obj = new Object();
            if (orginSouce == null) {
                obj.source = [];
                obj.total = 0;
            } else {
                obj.source = orginSouce;
                obj.total = orginSouce.shift().totalCount;
            }
            return obj;
        };
        /**
         * wyl 17-6-26
         * 去掉字符串里面的括号（包含中英文的全角半角4中）和空格
         */
        System.prototype.replaceKonggeKuohao = function (str) {
//			  var str1 = str.replace("(","").replace(")","").replace("（","").replace("）","").replace("（","").replace("）","").replace("（","").replace("）","");
//		    var reg=/\s+/g;
//		    var newStr = str1.replace(reg,"");

            return str;
        };

        System.prototype.getColorSection = function (color1, color2, valueMin, valueMax, values) {
            color1 = color1.replace("#", "");
            color2 = color2.replace("#", "");
            var color_min = Math.min(parseInt(color1, 16), parseInt(color2, 16));
            var color_max = Math.max(parseInt(color1, 16), parseInt(color2, 16));
            var color = [];
            for (var i = 0; i < values.length; i++) {
                var cc = color_min + (values[i].value - valueMin) / (valueMax - valueMin) * (color_max - color_min);
                color[i] = "#" + cc.toString(16).split(".")[0];
            }


            return color;
        };

        /**
         * (支持数结构)通用方法，通过key字段找出源数组中的与targetArr匹配的项(targetArr与sourceArr数据结构相同)，结果为一个或多个
         * key:String targetArr:Array sourceArr,要查找的数据源
         */
        System.prototype.getItemsByField = function (key, targetArr, sourceArr, childrenKey) {
            var returnArr = [];
            for (var i = 0; i < targetArr.length; i++) {
                for (var sIndex = 0; sIndex < sourceArr.length; sIndex++) {
                    if (sourceArr[sIndex][key] == targetArr[i][key]) {
                        returnArr.push(sourceArr[sIndex]);
                        break;
                    } else if (childrenKey != null && childrenKey != undefined) {
                        if (sourceArr[sIndex][childrenKey] != undefined && sourceArr[sIndex][childrenKey] != null) {
                            var childeReturnArr = this.getItemsByField(key, [
                                targetArr[i]
                            ], sourceArr[sIndex][childrenKey], childrenKey);

                            if (childeReturnArr.length > 0) {
                                returnArr = returnArr.concat(childeReturnArr);
                                break;
                            }

                        }
                    }
                }
            }

            return returnArr;
        };

        /**
         * 获取一个item 在数组中的位置
         */
        System.prototype.indexOf = function (targetArr, searchText, key) {
            var index = -1;
            for (var i = 0; i < targetArr.length; i++) {
                if (targetArr[i][key] == searchText) {
                    index = i;
                    break;
                }
            }

            return index;
        }


        /**
         * (支持数结构)通用方法，通过key字段找出源数组中的与valuesArr匹配的项(valuesArr是sourceArr中的key对应的值集合)，结果为一个或多个
         * key:String valuesArr:Array sourceArr,要查找的数据源
         */
        System.prototype.getItemByFieldValues = function (key, valuesArr, sourceArr, childrenKey) {

            var returnArr = [];
            for (var i = 0; i < valuesArr.length; i++) {
                for (var sIndex = 0; sIndex < sourceArr.length; sIndex++) {
                    if (sourceArr[sIndex][key] == valuesArr[i]) {
                        returnArr.push(sourceArr[sIndex]);
                        continue;
                    } else if (childrenKey != null && childrenKey != undefined) {
                        if (sourceArr[sIndex][childrenKey] != undefined && sourceArr[sIndex][childrenKey] != null) {
                            var childeReturnArr = this.getItemByFieldValues(key, [
                                valuesArr[i]
                            ], sourceArr[sIndex][childrenKey], childrenKey);

                            if (childeReturnArr.length > 0) {
                                returnArr = returnArr.concat(childeReturnArr);
                                break;
                            }

                        }

                    }
                }
            }

            return returnArr;
        };

        /**
         *获取与所传值数值的父节点一样的节点，即获取兄弟节点
         */
        System.prototype.getSameLevelSourceByParentId = function (key, valuesArr, sourceArr, childrenKey) {

            var returnArr = [];
            for (var i = 0; i < valuesArr.length; i++) {
                for (var sIndex = 0; sIndex < sourceArr.length; sIndex++) {
                    if (sourceArr[sIndex][key] == valuesArr[i]) {
                        returnArr.push(sourceArr[sIndex]);
                    } else if (childrenKey != null && childrenKey != undefined) {
                        if (sourceArr[sIndex][childrenKey] != undefined && sourceArr[sIndex][childrenKey] != null) {
                            var childeReturnArr = this.getItemByFieldValues(key, [
                                valuesArr[i]
                            ], sourceArr[sIndex][childrenKey], childrenKey);

                            if (childeReturnArr.length > 0) {
                                returnArr = returnArr.concat(childeReturnArr);
                                break;
                            }

                        }

                    }
                }
            }

            return returnArr;
        };

        /**
         * 判断数据内部数据是否是tree结构 key:数组项中有子节点的key。item[key]==null，表示没有子节点
         */
        System.prototype.isTree = function (key, sourceArr) {
            var isTreeFlag = false;
            for (var i = 0; i < sourceArr.length; i++) {
                if (sourceArr[i][key] != null) {
                    isTreeFlag = true;
                    break;
                }
            }
            return isTreeFlag;
        }

        /**
         * 将数据转换成ligerUI所需要的数据源
         */
        System.prototype.changeToLigerUISource = function (data) {
            var retArr = [];
            for (var i = 0; i < data.length; i++) {
                var item = {};
                item.label = data[i];
                item.code = data[i];
                retArr.push(item);
            }
            return retArr;
        }

        /**
         * 将数据转换成下拉列表(bootStrap)所需要的数据源
         */
        System.prototype.changeToDropDownSource = function (data) {
            var retArr = [];
            for (var i = 0; i < data.length; i++) {
                var item = {};
                item.text = data[i];
                item.id = data[i];
                retArr.push(item);
            }
            return retArr;
        }

        /**
         * 添加单层级下列列表标签
         */
        System.prototype.addOptionListFun = function (parent, data, valueField, textField) {
            parent.empty();
            if (data) {
                for (var i = 0; i < data.length; i++) {
                    var value = data[i][valueField];
                    var text = data[i][textField];
                    var option = $("<option></option>");
                    option.attr("value", value);
                    option.text(text);
                    parent.append(option);
                }
            }
        }

        /**
         * 添加分组下拉列表标签
         */
        System.prototype.addOptionListForGroupFun = function (parent, data, valueField, textField, childFiled) {
            parent.empty();
            if (data) {
                for (var i = 0; i < data.length; i++) {
                    var value = data[i][valueField];
                    var text = data[i][textField];
                    var option = $("<optgroup></optgroup>");
                    option.attr("label", text);
                    parent.append(option);
                    if (typeof (childFiled) == "undefined") {
                        childFiled = "children";
                    }
                    if (data[i].hasOwnProperty(childFiled)) {
                        this.addOptionListFun(option, data[i][childFiled], valueField, textField);
                    }
                }
            }
        }

        /**
         * 添加单层级下列列表标签
         */
        System.prototype.getContainerGapByScreenPixel = function () {
            var gap = 10;
            if (screen.width == LSComponent.GlobalVars.screenPixelAuto.screen1024_768.width && screen.height == LSComponent.GlobalVars.screenPixelAuto.screen1024_768.height) {
                gap = 10;
            } else if (screen.width == LSComponent.GlobalVars.screenPixelAuto.screen1280_800.width && screen.height == LSComponent.GlobalVars.screenPixelAuto.screen1280_800.height) {
                gap = 10;
            } else if (screen.width == LSComponent.GlobalVars.screenPixelAuto.screen1366_768.width && screen.height == LSComponent.GlobalVars.screenPixelAuto.screen1366_768.height) {
                gap = 10;
            }
            return gap;
        }

        /**
         * 获取页面自适应屏幕应该调整的高度值。 实际高度的差值>=最小高度 return 0 实际高度的差值<最小高度 return
         * 最小高度-实际高度
         */
        System.prototype.getPageAutoHeightDiff = function (minHeight, actualHeigth) {
            var diff = 0;
            if (actualHeigth < minHeight) {
                diff = minHeight - actualHeigth;
            }
            return diff;
        }

        System.prototype.getPageHeight = function () {
            var currentContentHeight = document.body.offsetHeight;
            if (window.screen.height > LSComponent.GlobalVars.pageMaxScreenHeight) {
                currentContentHeight = LSComponent.GlobalVars.pageMaxScreenHeight - (window.screen.height - document.body.offsetHeight);
            }
            if (currentContentHeight < LSComponent.GlobalVars.pageMinContentHeight) {
                currentContentHeight = LSComponent.GlobalVars.pageMinContentHeight;
            }

            return currentContentHeight;
        }

        /**
         * 按字段进行排序（数字） key:排序的字段名 sourceArr:数据源 sortType:排序类型 asc:升序；desc:降序
         */
        System.prototype.sortByField = function (key, sourceArr, sortType) {
            if (sortType == null || sortType == undefined) {
                sortType = "desc";
            }

            sourceArr.sort(function (a, b) {
                if (Number(a[key]) == Number(b[key])) {
                    return 0;
                } else {
                    if (sortType == "asc") {
                        return Number(a[key]) > Number(b[key]) ? 1 : -1;
                    } else if (sortType == "desc") {
                        return Number(a[key]) < Number(b[key]) ? 1 : -1;
                    }

                }
            });

            return sourceArr;
        }

        /**
         * 按字段进行排序（数字） key:排序的字段名 sourceArr:数据源，sourceArr的item为resultVO类型
         * sortType:排序类型 asc:升序；desc:降序
         */
        System.prototype.sortByResultVOField = function (key, sourceArr, sortType) {
            if (sortType == null || sortType == undefined) {
                sortType = "desc";
            }

            sourceArr.sort(function (a, b) {
                if (Number(a.props[key]) == Number(b.props[key])) {
                    return 0;
                } else {
                    if (sortType == "asc") {
                        return Number(a.props[key]) > Number(b.props[key]) ? 1 : -1;
                    } else if (sortType == "desc") {
                        return Number(a.props[key]) < Number(b.props[key]) ? 1 : -1;
                    }

                }
            });

            return sourceArr;
        }

        /**
         * 找出数组中key值的最大项
         */
        System.prototype.findMaxItemByField = function (key, sourceArr) {
            var maxValue = 0;
            var maxItem = null;
            for (var i = 0; i < sourceArr.length; i++) {
                if (sourceArr[i][key] > maxValue) {
                    maxValue = sourceArr[i][key];
                    maxItem = sourceArr[i];
                }
            }
            return maxItem;
        }

        /**
         * 显示空数据,$dom为jquery对象
         * tip为显示的文字信息，“没有符合条件的数据，请尝试其它搜索条件” 不能满足所有需求
         */
        System.prototype.showNull = function ($dom, _left, _top) {
            this.hideNull($dom);
            if (_left == undefined || _top == null) {
                _left = 0;
            }
            if (_top == undefined || _top == null) {
                _top = 0;
            }

            var $div = $("<div id='" + $dom.attr("id") + "_null' style='clear: both;padding-left:" + _left + "px;padding-top:" + _top + "px'>没有符合条件的数据，请尝试其它搜索条件。</div>");
            var width = $dom.width();
            if (width <= 0) {
                width = "100%";//默认高度为22px
            }
            $div.css("width", width);

            var height = $dom.height();
            if (height <= 0) {
                height = "22px";//默认高度为22px
            }
            $div.css("height", height);

            $dom.after($div);

            $dom.css("display", "none");
        };

        /**
         * 隐藏空数据,$dom为jquery对象
         */
        System.prototype.hideNull = function ($dom) {
            if ($dom.next().length > 0 && $dom.next().attr("id") == ($dom.attr("id") + "_null")) {
                $dom.css("display", "block");
                $dom.next().remove();
            }

        }

        /**
         * 根据所传数据获取是向上还是向下箭头
         */
        System.prototype.getUpDownIcon = function (value) {
            var str = "";
            if (value == null) {
                str = "";
            } else {
                if (value > 0)
                    str = "<i class='icon-percent-1 upClass'></i>";
                else if (value < 0)
                    str = "<i class='icon-percent-2 downClass'></i>";
                else
                    str = "<i class='icon-percent'></i>";
            }

            return str;
        };
        System.prototype.getUpDownTextClass = function (value) {
            var str = "";
            if (value > 0)
                str = "upClass";
            else if (value < 0)
                str = "downClass";
            else
                str = "";

            return str;
        };


        /**
         * 将平铺结构转换成树形结构（对象不改变） idField 为分组id
         * [{id:'a',name:'北京',cid:'aa',cname:'海淀'},{id:'a',name:'北京',cid:'bb',cname:'大兴'},{id:'a',name:'北京',cid:'cc',cname:'朝阳'}]
         * 结果：[{id:'a',name:'北京',children:[{id:'a',name:'北京',cid:'aa',cname:'海淀'},{id:'a',name:'北京',cid:'bb',cname:'大兴'},{id:'a',name:'北京',cid:'cc',cname:'朝阳'}]}]
         */
        System.prototype.listToTree = function (list, idField, nameField) {
            if (list && list.length > 0) {
                var newArr = [];
                var existObj = {};

                list.forEach(function (item, index, arr) {
                    if (existObj.hasOwnProperty(item[idField])) {
                        newArr[existObj[item[idField]]].children.push(item);
                    } else {
                        var temp = {};
                        temp[idField] = item[idField];
                        if (nameField)
                            temp[nameField] = item[nameField];
                        temp.children = [
                            item
                        ];
                        newArr.push(temp);
                        existObj[item[idField]] = newArr.length - 1;
                    }
                });

                return newArr;
            } else {
                return [];
            }
        }

        /**
         * 将平铺结构转换成树形结构（对象改变） idField 为分组id isDimension 是否为参数字典
         * 如果是，则需要从attributes拿
         * [{id:'a',name:'北京',cid:'aa',cname:'海淀'},{id:'a',name:'北京',cid:'bb',cname:'大兴'},{id:'a',name:'北京',cid:'cc',cname:'朝阳'}]
         * 结果：[{id:'a',name:'北京',children:[{id:'aa',name:'海淀',cid:'aa',cname:'海淀'},{id:'bb',name:'大兴',cid:'bb',cname:'大兴'},{id:'cc',name:'朝阳',cid:'cc',cname:'朝阳'}]}]
         */
        System.prototype.listToTreeComplete = function (list, idField, nameField, cidField, cnameField, isDimension) {
            if (list && list.length > 0) {
                var newArr = [];
                var existObj = {};

                list.forEach(function (item, index, arr) {
                    if (existObj[item[idField]]) {
                        newArr[existObj[item[idField]]].children.push(item);
                        item[idField] = isDimension ? item.attributes[cidField] : item[cidField];
                        item[nameField] = isDimension ? item.attributes[cnameField] : item[cnameField];
                    } else {
                        var temp = {};
                        existObj[item[idField]] = newArr.length;
                        temp[idField] = item[idField];
                        if (nameField)
                            temp[nameField] = item[nameField];
                        item[idField] = isDimension ? item.attributes[cidField] : item[cidField];
                        item[nameField] = isDimension ? item.attributes[cnameField] : item[cnameField];
                        temp.children = [
                            item
                        ];
                        newArr.push(temp);
                    }
                });

                return newArr;
            } else {
                return [];
            }
        };

        /**
         * wyl
         * 2018-2-27修改
         */
        System.prototype.treeToList = function (sourceArr, childrenKey, arr) {
            var newArr;
            if (arr == null || arr == undefined)
                newArr = [];
            else
                newArr = arr;
            for (var i = 0; i < sourceArr.length; i++) {
                var items = sourceArr[i];
//				if(items.childrenKey != null){
//					itemObj.pId = items.parentid;
//				}
                newArr.push(items);
                if (items[childrenKey] != null && items[childrenKey] != undefined) {
                    this.treeToList(items.children, "children", newArr);
                }
            }
            return newArr;
        };

        /**
         * zhangjie 17-3-31
         * 根据数据的length判断pie取色系值
         */
        System.prototype.getPieSeriesColorsByLength = function (count) {
            var seriesColors = [];
            if (count > 0 && count < 5) {
                seriesColors = LSComponent.GlobalVars.chartSeriesColors.pie1;
            } else if (count >= 5 && count < 13) {
                seriesColors = LSComponent.GlobalVars.chartSeriesColors.pie2;
            }
//			else if(count >= 9 && count < 17){
//				seriesColors = LSComponent.GlobalVars.chartSeriesColors.pie3;
//			}
            else if (count >= 13) {
                seriesColors = LSComponent.GlobalVars.chartSeriesColors.pie3;
            }
            return seriesColors;
        };
        System.prototype.getDoublePieSeriesColors = function () {

            return [LSComponent.GlobalVars.chartSeriesColors.doublePieInner, LSComponent.GlobalVars.chartSeriesColors.doublePieOut];
        };
        System.prototype.convert2SelectSource = function (keyField, valueField, source) {
            var target = [];
            if (source && source.length > 0) {
                for (var i = 0; i < source.length; i++) {
                    target.push({id: source[i][keyField], text: source[i][valueField]});
                }
            }
            return target;
        };
        /**
         * liujiajia 17-7-3
         * 判斷是否為財政直管縣
         */
        System.prototype.isCzCounty = function (code) {
            var czCodes = [411681, 410122, 410327, 410425, 410727, 410825, 410926, 411024, 411224, 411328, 411426, 411526, 411625, 411724];

            if (!code || code.length < 6) return false;
            var clen = code.length;
            if (clen > 6) code = code.slice(clen - 6, clen);

            for (var i = 0, len = czCodes.length; i < len; i++) {
                if (czCodes[i] == code) {
                    return true;
                }
            }

            return false;
        };
        /**
         * 行政直管县
         * @param code
         * @returns {boolean}
         */
        System.prototype.isXZCounty = function (code) {
            var czCodes = [410181, 411481, 411381, 411525, 410225, 410526, 411729, 410482, 410728, 411628];

            if (!code || code.length < 6) return false;
            var clen = code.length;
            if (clen > 6) code = code.slice(clen - 6, clen);

            for (var i = 0, len = czCodes.length; i < len; i++) {
                if (czCodes[i] == code) {
                    return true;
                }
            }

            return false;
        };
        /** 曹永强
         * 删除数组中某个对象
         * 例：删除 arr = [{a: 1, b: 1},{a: 2, b: 2},{a: 3, b: 3}] 中 a = 2 的对象
         *      removeObjInArray('a', 2, arr)
         * @param field 数组里边对象要比较的字段
         * @param value 对应的值
         * @param arr 原数组
         * @returns {*} 返回一个新数组
         */
        System.prototype.removeObjInArray = function (field, value, arr) {
            var newArray = arr;
            if (!field) return;
            for (var i = arr.length - 1; i >= 0; i--) {
                if (arr[i][field] == value) {
                    newArray.splice(i, 1);
                }
            }
            return newArray;
        };

        System.prototype.UUID = function () {
            var d = new Date().getTime();
            var uuid = 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
                var r = (d + Math.random() * 16) % 16 | 0;
                d = Math.floor(d / 16);
                return (c == 'x' ? r : (r & 0x3 | 0x8)).toString(16);
            });
            return uuid;
        };

        /**
         * 构造预算执行年度下拉列表数据源
         * @param minDate
         * @param maxDate
         * @returns {Array}
         */
        System.prototype.buildNPCYear = function (minDate, maxDate) {
            var arr = [];
            for (var i = maxDate; i >= minDate; i--) {
                if (i == maxDate) {
                    arr.push({id: i, text: i + "年预算", type: 1});
                } else {
                    arr.push({id: i, text: i + "年执行", type: 2});
                }
            }
            return arr;
        };

        /**
         * echart tooltip icon
         * @param color
         * @returns {String}
         */
        System.prototype.getTooltipIcon = function (color) {
            var icon = "";
            if(color){
                icon = "<i class='ls-echart-tooltip-icon' style='background-color:" + color +"'></i>";
            }
            return icon;
        };
        
        System.prototype.sysDateTodDimensionDate=function(data){
        	var source={};
        	
        }
        
    };

    LSComponent.Utils = LSComponent.Utils || {};
    LSComponent.Utils.System = new System();

}());