﻿/*
 * LSComponent 字符串和数值格式化工具类
 * author liliuqing
 * modified by liliuqing
 * version: "2018.06.29.01"
 */
(function () {
    /**
     * 关于值处理的对象
     *
     * @param val
     *            {string}
     * @example trimStart(" 123456");
     */
    var Velue = function () {

        /**
         * 去除开始处空格
         *
         * @param val
         *            {string}
         * @example trimStart(" 123456");
         */
        Velue.prototype.trimStart = function (val) {
            return val.replace(/(^\s*)/g, "");
        }

        /**
         * 去除结尾处空格
         *
         * @param val
         *            {string}
         * @param example
         *            trimEnd("123456 ");
         */
        Velue.prototype.trimEnd = function (val) {
            return val.replace(/(\s*$)/g, "");
        }

        /**
         * 去除首尾处空格
         *
         * @param val
         *            {string}
         * @param example
         *            trimEnd(" 123456 ");
         */
        Velue.prototype.trim = function (val) {
            return val.replace(/(^\s*)/g, "").replace(/(\s*$)/g, "");
        }
        /**
         * 去除回车换行
         *
         * @param val
         *            {string}
         * @param example
         *            trimEnd(" 123 456");
         */
        Velue.prototype.delEnter = function (val) {
            return val.replace(/[\r\n]/g, "");
        }
        /**
         * 格式化数字,添加千分位并且保留N位小数位数，并且'-','null'识别为NAN
         *
         * @param value
         *            {string}
         * @param intBit{number}
         * @example format("1234.456",0)=1234;
         */
        Velue.prototype.format = function (value, intBit) {
            if (typeof value === "string") {
                value = value * 1;
            }
            value = value.toFixed(intBit);
            var val = value.replace(/^(\d+)((\.\d+)?)$/, function (s, s1, s2) {
                return s1.replace(/\d{1,3}(?=(\d{3})+$)/g, '$&,') + s2;
            });
            return val;
        };
        // 获取文本中的数字并格式化
        Velue.prototype.formatNumberTextMixed = function (_value) {
            var reValue = "";
            if ("-" == _value || null == _value || (typeof _value == "string" && ("" == _value || "999999" == _value))) {
                reValue = "-";
            } else {
                // 是否含有数字；
                if (!/\d+/.test(_value)) {
                    reValue = _value;
                } else {
                    var formatterArr = [];
                    // 获取数字；
                    var reg = /(\d|\.)+/g;
                    var strObj = _value.match(reg);
                    var reStr = strObj.join(',');// string
                    var strArr = reStr.split(',');// 数组
                    var n = 0;
                    for (var i = int = 0; i < strArr.length; i++) {
                        // 判断n 的传值,是否含有‘.’;
                        if (/\.+/.test(strArr[i])) {
                            n = 2;
                        }
                        formatterArr.push(this.formatNumber(strArr[i], n));// 格式化后的数字组成的数组；
                    }
                    // 将格式化的数字放回到字符串中；
                    var strArr1 = _value.split(reg);
                    var j = 0;
                    for (var i = 0; i < strArr1.length; i++) {
                        // 是否含有数字；
                        if (/(\d|\.)+/.test(strArr1[i])) {
                            strArr1[i] = formatterArr[j];
                            j++;
                        }
                    }
                    reValue = strArr1.join('');
                }
            }
            return reValue;
        };

        /**
         * 格式化数字,添加千分位并且保留N位小数位数,并且支持单位转换，常用
         * @example format("123456.0000",2) = 123,456.00
         * @param value 数据源
         * @param bit 小数位数
         * @param unitType 格式化后的数值单位
         * @param valueUnitType 数据源的数值单位
         * @param isHideZero 是否隐藏数值0，默认不对0作处理，允许显示为0
         * @returns {string}
         */
        Velue.prototype.formatNumberUnit = function (value, bit, unitType, valueUnitType, isHideZero) {
            var temp = value;

            if (isHideZero) {//如果隐藏数值0
                if (value == 0) {
                    temp = "";
                    return temp;
                }
            }

            if (unitType) {
                temp = this.unitFormat(value, unitType, valueUnitType);
            }

            temp = this.formatNumber(temp, bit);


            return temp;


        }

        /**
         * 数值单位转换
         * @param value 数据源
         * @param type 要转换成的单位类型
         * @param valueType 数据源单位类型
         * @returns {*}
         */
        Velue.prototype.unitFormat = function (value, type, valueType) {
            if (value || value != "" || value != "-" || value != "NaN" || value != "NAN") {

                //将值换算成最基本单位(元)
                if (valueType) {
                    if (valueType == 0) {// 元
                        value = value;
                    } else if (valueType == 1) {// 万元
                        value = value * 10000;
                    } else if (valueType == 2) {// 亿元
                        value = value * 100000000;
                    } else if (valueType == 3) {// 百亿元
                        value = value * 10000000000;
                    }
                }
                if (type == 0) {// 元
                    value = value;
                } else if (type == 1) {// 万元
                    value = value / 10000;
                } else if (type == 2) {// 亿元
                    value = value / 100000000;
                } else if (type == 3) {// 百亿元
                    value = value / 10000000000;
                }
            }

            //科学计数法转为一般数字
            if(value && (value+"").toUpperCase().indexOf("E") >= 0){
                value = (value).toFixed(18).replace(/\.?0+$/, "");
            }

            return value;
        }

        /**
         * 格式化数字,添加千分位并且保留N位小数位数,并且支持单位转换，常用
         * @example format("123456.0000",2) = 123,456.00
         * @param s 数据源
         * @param n 小数位数
         * @param _unitType 格式化后的数值单位
         * @param _valueType 数据源的数值单位
         * @param _isHideZero 是否隐藏数值0，默认不对0作处理，允许显示为0
         * @returns {string}
         */
        Velue.prototype.formatNumber = function (s, n, _unitType, _valueUnitType, _isHideZero) {
            // var temp = "";

            if ("-" == s || null == s || isNaN(s) || (typeof s == "string" && ("" == s.trim()))) {
                var temp = "-"
            } else {
                var flag = true;
                s = s + '';
                if (s.indexOf("-") >= 0) {
                    s = parseFloat(s.replace(/[^\d\.]/g, "")).toFixed(n) + "";
                    flag = false;
                } else {
                    s = parseFloat(s.replace(/[^\d\.-]/g, "")).toFixed(n) + "";
                }
                var l = s.split(".")[0].split("").reverse();
                if (n > 0) {
                    var r = s.split(".")[1];
                    var t = "";
                    for (var i = 0; i < l.length; i++) {
                        t += l[i] + ((i + 1) % 3 == 0 && (i + 1) != l.length ? "," : "");
                    }
                    if (flag == false) {
                        var temp = "-" + t.split("").reverse().join("") + "." + r;
                    } else {
                        var temp = t.split("").reverse().join("") + "." + r;
                    }
                } else {
                    var t = "";
                    for (var i = 0; i < l.length; i++) {
                        t += l[i] + ((i + 1) % 3 == 0 && (i + 1) != l.length ? "," : "");
                    }
                    var temp = t.split("").reverse().join("");
                    if (flag == false) {
                        temp = "-" + temp;
                    } else {
                        temp = temp;
                    }
                }
            }

            if (temp == "-") {
                temp = "";
            }

            return temp;
        }

        /**
         * 源自HighCharts的numberFormat方法
         */
        Velue.prototype.numberFormat = function (number, decimals, decPoint, thousandsSep) {
            var lang = {
                loading: 'Loading...',
                months: ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'],
                shortMonths: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
                weekdays: ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'],
                decimalPoint: '.',
                resetZoom: 'Reset zoom',
                resetZoomTitle: 'Reset zoom level 1:1',
                thousandsSep: ','
            }, n = number, c = isNaN(decimals = Math.abs(decimals)) ? 2 : decimals, d = decPoint === undefined ? lang.decimalPoint : decPoint, t = thousandsSep === undefined ? lang.thousandsSep : thousandsSep, s = n < 0 ? "-" : "", i = String(pInt(n = Math.abs(+n || 0).toFixed(c))), j = i.length > 3 ? i.length % 3 : 0;
            return s + (j ? i.substr(0, j) + t : "") + i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + t) + (c ? d + Math.abs(n - i).toFixed(c).slice(2) : "");
        }

        function pInt(s, mag) {
            return parseInt(s, mag || 10);
        }

        /**
         * 反序列化为对象
         *
         * @param obj
         *            {string}
         * @example jsonParse("{'':'','':'' }");
         */
        Velue.prototype.jsonParse = function (obj) {
            return JSON.parse(obj);
        }

        /**
         * wyl 17-3-27 返回小于0.01 的小数后面第一个非0 数值 eg:0.00045678 --> 0.0004
         */
        Velue.prototype.getLastNumber = function (key) {
            if (key == "0")
                return key;
            var point = key.toString().split(".")[1];
            var newValue = "0.";
            var lastNum = 0;
            for (var i = 0; i < point.length; i++) {
                var curr = point.substr(i, 1);
                if (curr == "0") {
                    newValue += "0";

                } else {
                    lastNum = point[i];
                    break;
                }
            }
            return newValue + lastNum;
        };

        /**
         * 获取url传参值
         *
         * @param key
         *            {string}
         * @param example
         *            getUrlValue("name");
         */
        Velue.prototype.getUrlValue = function (key) {
            var reg = new RegExp("(^|&)" + key + "=([^&]*)(&|$)", "i");
            var r = window.location.search.substr(1).match(reg);
            if (r != null) {
                return unescape(r[2]);
            } else {
                return null;
            }
        }

        /**
         * 字符串每个字母后添加换行符\n
         */
        Velue.prototype.addWordWrapSymbol = function (val) {
            if (val == "" || val == undefined || val == null) {
                return;
            }

            var arr = val.split("");
            var retValue = "";
            for (var i = 0; i < arr.length; i++) {
                retValue += arr[i] + "\n";
            }
            return retValue;
        }

        Velue.prototype.formatStrToNumber = function (val) {
            var retVal = 0;
            if (val.indexOf("/") >= 0) {// 是分数
                var arr = val.split("/");
                retVal = Number(arr[0]) / Number(arr[1]);
            } else {
                retVal = Number(val);
            }

            return retVal;

        }

        /**
         * 给字符串添加换行符\n。如“灵数科技”，改为“灵\n数\n科\n技”
         * @param value 字符串
         */
        Velue.prototype.addEnter = function (value) {
            var arrValue = value.split("");
            var retValue = "";
            for (var i = 0; i < arrValue.length; i++) {
                retValue += arrValue[i] + "\n";
            }
            return retValue;
        }

        /**
         * URL参数处理函数
         *
         * @param val
         *            {string}
         * @example trimStart(" 123456");
         */
        Velue.prototype.getRequest = function () {
            var url = location.search; //获取url中"?"符后的字串
            var theRequest = new Object();
            if (url.indexOf("?") != -1) {
                var str = url.substr(1);
                var strs = str.split("&");
                for(var i = 0; i < strs.length; i ++) {
                    theRequest[strs[i].split("=")[0]]=decodeURIComponent(strs[i].split("=")[1]);
                }
            }
            return theRequest;
        };
        /**
         * 获取当前时序进度(按天)
         * @returns {string}
         */
        Velue.prototype.getTimeProgress = function () {
            var currentYear = new Date().getFullYear().toString();
            var hasTimestamp = new Date() - new Date(currentYear);
            var currentDays = Math.ceil(hasTimestamp / 86400000) + 1;
            var progress = 100*currentDays/365;
            return this.formatNumber(progress, 2);
        }

    };

    LSComponent.Utils = LSComponent.Utils || {};
    LSComponent.Utils.Value = new Velue();

}());